==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/AzureFirstPartyManagedCertificateParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.AzureFirstPartyManagedCertificateParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Azure FirstParty Managed Certificate provided by other first party resource providers to enable HTTPS.
 * @property subjectAlternativeNames The list of SANs.
 * @property type The type of the secret resource.
 * Expected value is 'AzureFirstPartyManagedCertificate'.
 */
public data class AzureFirstPartyManagedCertificateParametersArgs(
    public val subjectAlternativeNames: Output<List<String>>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.AzureFirstPartyManagedCertificateParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.cdn.inputs.AzureFirstPartyManagedCertificateParametersArgs =
        com.pulumi.azurenative.cdn.inputs.AzureFirstPartyManagedCertificateParametersArgs.builder()
            .subjectAlternativeNames(
                subjectAlternativeNames?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureFirstPartyManagedCertificateParametersArgs].
 */
@PulumiTagMarker
public class AzureFirstPartyManagedCertificateParametersArgsBuilder internal constructor() {
    private var subjectAlternativeNames: Output<List<String>>? = null

    private var type: Output<String>? = null

    /**
     * @param value The list of SANs.
     */
    @JvmName("gitgfyjpcfalastv")
    public suspend fun subjectAlternativeNames(`value`: Output<List<String>>) {
        this.subjectAlternativeNames = value
    }

    @JvmName("inwbsqbdvcqjeslu")
    public suspend fun subjectAlternativeNames(vararg values: Output<String>) {
        this.subjectAlternativeNames = Output.all(values.asList())
    }

    /**
     * @param values The list of SANs.
     */
    @JvmName("ugrkvxfhisosjjkd")
    public suspend fun subjectAlternativeNames(values: List<Output<String>>) {
        this.subjectAlternativeNames = Output.all(values)
    }

    /**
     * @param value The type of the secret resource.
     * Expected value is 'AzureFirstPartyManagedCertificate'.
     */
    @JvmName("brlrvkhbmrcmsyke")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The list of SANs.
     */
    @JvmName("tltudscrvdfprqpr")
    public suspend fun subjectAlternativeNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subjectAlternativeNames = mapped
    }

    /**
     * @param values The list of SANs.
     */
    @JvmName("xxhvyvjwanfrxtth")
    public suspend fun subjectAlternativeNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subjectAlternativeNames = mapped
    }

    /**
     * @param value The type of the secret resource.
     * Expected value is 'AzureFirstPartyManagedCertificate'.
     */
    @JvmName("vtfrqgfceyfbonff")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AzureFirstPartyManagedCertificateParametersArgs =
        AzureFirstPartyManagedCertificateParametersArgs(
            subjectAlternativeNames = subjectAlternativeNames,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/AzureFirstPartyManagedCertificateParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.AzureFirstPartyManagedCertificateParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Azure FirstParty Managed Certificate provided by other first party resource providers to enable HTTPS.
 * @property subjectAlternativeNames The list of SANs.
 * @property type The type of the secret resource.
 * Expected value is 'AzureFirstPartyManagedCertificate'.
 */
public data class AzureFirstPartyManagedCertificateParametersArgs(
    public val subjectAlternativeNames: Output<List<String>>? = null,
    public val type: Output<String>,
) :
    ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.AzureFirstPartyManagedCertificateParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.cdn.inputs.AzureFirstPartyManagedCertificateParametersArgs =
        com.pulumi.azurenative.cdn.inputs.AzureFirstPartyManagedCertificateParametersArgs.builder()
            .subjectAlternativeNames(
                subjectAlternativeNames?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AzureFirstPartyManagedCertificateParametersArgs].
 */
@PulumiTagMarker
public class AzureFirstPartyManagedCertificateParametersArgsBuilder internal constructor() {
    private var subjectAlternativeNames: Output<List<String>>? = null

    private var type: Output<String>? = null

    /**
     * @param value The list of SANs.
     */
    @JvmName("moidwmxurptvqjdx")
    public suspend fun subjectAlternativeNames(`value`: Output<List<String>>) {
        this.subjectAlternativeNames = value
    }

    @JvmName("trmvsauwbooufxkf")
    public suspend fun subjectAlternativeNames(vararg values: Output<String>) {
        this.subjectAlternativeNames = Output.all(values.asList())
    }

    /**
     * @param values The list of SANs.
     */
    @JvmName("xkriqmwvegmgucfe")
    public suspend fun subjectAlternativeNames(values: List<Output<String>>) {
        this.subjectAlternativeNames = Output.all(values)
    }

    /**
     * @param value The type of the secret resource.
     * Expected value is 'AzureFirstPartyManagedCertificate'.
     */
    @JvmName("fbtrkuhqbncgrswf")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The list of SANs.
     */
    @JvmName("nnbvxqpwtbdthtmk")
    public suspend fun subjectAlternativeNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subjectAlternativeNames = mapped
    }

    /**
     * @param values The list of SANs.
     */
    @JvmName("avkgcaibmckamuwv")
    public suspend fun subjectAlternativeNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.subjectAlternativeNames = mapped
    }

    /**
     * @param value The type of the secret resource.
     * Expected value is 'AzureFirstPartyManagedCertificate'.
     */
    @JvmName("ugbuaegkdpcoquve")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): AzureFirstPartyManagedCertificateParametersArgs =
        AzureFirstPartyManagedCertificateParametersArgs(
            subjectAlternativeNames = subjectAlternativeNames,
            type = type ?: throw PulumiNullFieldException("type"),
        )
}
